@@ -397,6 +397,8 @@
                 (equal? '("foo" "bar" "baz")
                         (read (sys:make-input-port (car pipe))))))))
 
+; XXX should also test built-in ARGV primitive
+
 (test (let ((pipe (sys:pipe)))
         (cond ((zero? (sys:fork))
                 (sys:dup2 (cadr pipe) 1)
@@ -406,6 +408,15 @@
                 (equal? (string-append "hello" (string #\newline))
                         (sys:read (car pipe) 1024))))))
 
+(test (let ((pipe (sys:pipe))) ; SYSTEM of core S9, not of SYS:
+        (cond ((zero? (sys:fork))
+                (sys:dup2 (cadr pipe) 1)
+                (system "echo hello")
+                (sys:exit))
+              (else
+                (equal? (string-append "hello" (string #\newline))
+                        (sys:read (car pipe) 1024))))))
+
 (test (sys:unlink "testprog"))
 
 ; ----- Select ---------------------------------------------------------------
@@ -535,6 +546,9 @@
 (test (sys:getenv "HOME"))
 (fail (sys:getenv ""))
 
+(test (environ "HOME")) ; these two are in fact not in SYS:
+(fail (environ ""))
+
 (test (sys:getpid))
 
 (test (sys:getgid))
